package at.ac.uibk.gitsearch.service.dto;

import java.util.stream.Collectors;

import org.springframework.security.oauth2.client.registration.ClientRegistration;

/**
 * transfers infos of an OAuth2Config to client
 * @author Michael Breu
 *
 */
public class OAuth2ConfigDTO {
	

	private String registrationId;
	private String clientURL;
	private String scopes;
	
	public String getRegistrationId() {
		return registrationId;
	}
	public String getClientURL() {
		return clientURL;
	}
	public String getScopes() {
		return scopes;
	}
	
	public OAuth2ConfigDTO(ClientRegistration registration) {
		clientURL = registration.getRedirectUriTemplate();
		registrationId = registration.getRegistrationId();
		scopes = registration.getScopes().stream().collect(Collectors.joining( "," ));
	}

	public OAuth2ConfigDTO() {
		// JSON
	}

	@Override
	public final int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((clientURL == null) ? 0 : clientURL.hashCode());
		result = prime * result + ((registrationId == null) ? 0 : registrationId.hashCode());
		result = prime * result + ((scopes == null) ? 0 : scopes.hashCode());
		return result;
	}
	@Override
	public final boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (!(obj instanceof OAuth2ConfigDTO)) {
			return false;
		}
		OAuth2ConfigDTO other = (OAuth2ConfigDTO) obj;
		if (clientURL == null) {
			if (other.clientURL != null)
				return false;
		} else if (!clientURL.equals(other.clientURL))
			return false;
		if (registrationId == null) {
			if (other.registrationId != null)
				return false;
		} else if (!registrationId.equals(other.registrationId))
			return false;
		if (scopes == null) {
			if (other.scopes != null)
				return false;
		} else if (!scopes.equals(other.scopes))
			return false;
		return true;
	}
	
	@Override
	public String toString() {
		return "OAuth2ConfigDTO [for '" + registrationId + "']";
	}
}
